%define anolis_release 1
%define aprver 1

%undefine _package_note_flags

# Disable .la file removal since the .la file is exported via apr-config.
%global __brp_remove_la_files %nil

Summary: Apache Portable Runtime library
Name: apr
Version: 1.7.4
Release: %{anolis_release}%{?dist}
# ASL 2.0: everything
# ISC: network_io/apr-1.4.6/network_io/unix/inet_?to?.c
# BSD with advertising: strings/apr_snprintf.c, strings/apr_fnmatch.c,
#                   include/apr_fnmatch.h, misc/unix/getopt.c,
#                   file_io/unix/mktemp.c, strings/apr_strings.c
# BSD (3-clause): strings/apr_strnatcmp.c, include/apr_strings.h
License: ASL 2.0 and BSD with advertising and ISC and BSD
URL: https://apr.apache.org/
Source0: https://www.apache.org/dist/apr/%{name}-%{version}.tar.bz2
Patch1: apr-1.7.2-libdir.patch
Patch2: apr-1.2.7-pkgconf.patch
Patch3: apr-1.7.0-deepbind.patch
Patch4: apr-1.7.2-autoconf.patch
Patch6: apr-1.7.2-disable-freebind-bind-test.patch
BuildRequires: gcc, autoconf, libtool, libuuid-devel, python3
BuildRequires: make

%description
The mission of the Apache Portable Runtime (APR) is to provide a
free library of C data structures and routines, forming a system
portability layer to as many operating systems as possible,
including Unices, MS Win32, BeOS and OS/2.

%package devel
Summary: APR library development kit
Conflicts: subversion-devel < 0.20.1-2
Requires: apr = %{version}-%{release}, pkgconfig

%description devel
This package provides the support files which can be used to 
build applications using the APR library.  The mission of the
Apache Portable Runtime (APR) is to provide a free library of 
C data structures and routines.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1

%build
# regenerate configure script etc.
./buildconf

# Forcibly prevent detection of shm_open (which then picks up but
# does not use -lrt).
export ac_cv_search_shm_open=no

# Forcibly disable sctp protocol support
export apr_cv_sctp=no

%configure \
        --includedir=%{_includedir}/apr-%{aprver} \
        --with-installbuilddir=%{_libdir}/apr-%{aprver}/build \
        --with-devrandom=/dev/urandom \
        --disable-static
%{make_build}

%install
%{make_install}

mkdir -p $RPM_BUILD_ROOT/%{_datadir}/aclocal
for f in find_apr.m4 apr_common.m4; do
 install -p -m 644 build/$f $RPM_BUILD_ROOT/%{_datadir}/aclocal
done

# Trim exported dependecies
sed -ri '/^dependency_libs/{s,-l(uuid|crypt) ,,g}' \
      $RPM_BUILD_ROOT%{_libdir}/libapr*.la
sed -ri '/^LIBS=/{s,-l(uuid|crypt) ,,g;s/  */ /g}' \
      $RPM_BUILD_ROOT%{_bindir}/apr-%{aprver}-config
sed -ri '/^Libs/{s,-l(uuid|crypt) ,,g}' \
      $RPM_BUILD_ROOT%{_libdir}/pkgconfig/apr-%{aprver}.pc

# Unpackaged files:
rm -f $RPM_BUILD_ROOT%{_libdir}/apr.exp \
      $RPM_BUILD_ROOT%{_libdir}/libapr-*.a

sed -i '1s,/.*,/usr/bin/python3,' build/gen-build.py
for f in build/gen-build.py build/install.sh build/config.*; do
    install -c -m755 $f $RPM_BUILD_ROOT%{_libdir}/apr-%{aprver}/build
done

%check
# Fail if LFS support isn't present in a 32-bit build, since this
# breaks ABI and the soname doesn't change: see #254241
if grep 'define SIZEOF_VOIDP 4' include/apr.h \
   && ! grep off64_t include/apr.h; then
  cat config.log
  : LFS support not present in 32-bit build
  exit 1
fi
pushd test
  %make_build
  ./testall -v -q
popd

%generate_compatibility_deps

%files
%dir %{abidir}
%{_libdir}/libapr-%{aprver}.so.*
%{abidir}/libapr-%{aprver}.dump

%files doc
%doc CHANGES LICENSE NOTICE README*

%files devel
%doc docs/APRDesign.html docs/canonical_filenames.html
%doc docs/incomplete_types docs/non_apr_programs
%{_bindir}/apr-%{aprver}-config
%{_libdir}/libapr-%{aprver}.la
%{_libdir}/libapr-%{aprver}.so
%{_libdir}/pkgconfig/*.pc
%dir %{_libdir}/apr-%{aprver}
%dir %{_libdir}/apr-%{aprver}/build
%{_libdir}/apr-%{aprver}/build/*
%dir %{_includedir}/apr-%{aprver}
%{_includedir}/apr-%{aprver}/*.h
%{_datadir}/aclocal/*.m4

%changelog
* Wed May 17 2023 Funda Wang <fundawang@yeah.net> - 1.7.4-1
- New version 1.7.4

* Wed Apr 19 2023 Funda Wang <fundawang@yeah.net> - 1.7.3-1
- New version 1.7.3

* Mon Mar 27 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.7.2-2
- Del Specific Fields

* Thu Feb 9 2023 Funda Wang <fundawang@yeah.net> - 1.7.2-1
- New version 1.7.2
- Disable freebind port bind test, as it random fails in our buildbot

* Mon Jan 09 2023 Kaihao Bai <carlo.bai@linux.alibaba.com> - 1.7.0-2
- add doc package

* Mon May 23 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.7.0-1
- init from upstream
